LoadFitbitData: Load a Fitbit archive from disk

LoadFitbitDataR Documentation

Load a Fitbit archive from disk

Description

Load a Fitbit archive, as downloaded from fitbit.com, Settings, Data Export, Request Data. The downloaded zip file must be extracted into a folder. See below for an example.

Usage

LoadFitbitData(input_path)

Arguments

input_path

String containing the path of the extracted Fitbit archive. The string should end on a 'FirstnameLastname' directory.

Value

A data frame keyed on date and one column per metric.

Examples

## Not run: 
data <- LoadFitbitData("/path/to/MyFitbitData/FirstnameLastname/")
head(data)
PlotMetrics(data)
PlotMetrics(data %>% dplyr::select(date, VeryActiveMinutes))
PlotWeeklyMetrics(data)
PlotWeekdayMetrics(data)
PlotTimeAtRest(data)
PlotMinutesAwakeVsStartHour(data)

## End(Not run)

kaybrodersen/FitbitAnalysis documentation built on Feb. 1, 2023, 5:53 a.m.