| LoadFitbitData | R Documentation |
Load a Fitbit archive, as downloaded from fitbit.com, Settings, Data Export, Request Data. The downloaded zip file must be extracted into a folder. See below for an example.
LoadFitbitData(input_path)
input_path |
String containing the path of the extracted Fitbit archive. The string should end on a 'FirstnameLastname' directory. |
A data frame keyed on date and one column per metric.
## Not run:
data <- LoadFitbitData("/path/to/MyFitbitData/FirstnameLastname/")
head(data)
PlotMetrics(data)
PlotMetrics(data %>% dplyr::select(date, VeryActiveMinutes))
PlotWeeklyMetrics(data)
PlotWeekdayMetrics(data)
PlotTimeAtRest(data)
PlotMinutesAwakeVsStartHour(data)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.